@@ -6,7 +6,8 @@
 #' @param socialmedia Character string. Identifier for social media API to authenticate, set to \code{"youtube"}.
 #' @param apiKey Character string. Google developer API key to authenticate.
 #' @param ... Additional parameters passed to function. Not used in this method.
-#'
+#' @param verbose Logical. Output additional information. Default is \code{TRUE}.
+#' 
 #' @return A \code{credential} object containing an api key \code{$auth} and social media type descriptor
 #'   \code{$socialmedia} set to \code{"youtube"}. Object has the class names \code{"credential"} and \code{"youtube"}.
 #'
@@ -19,10 +20,9 @@
 #' }
 #'
 #' @export
-Authenticate.youtube <- function(socialmedia, apiKey, ...) {
-  if (missing(apiKey)) {
-    stop("Missing YouTube API key.", call. = FALSE)
-  }
+Authenticate.youtube <- function(socialmedia, apiKey, ..., verbose = TRUE) {
+  
+  if (missing(apiKey)) stop("Missing YouTube API key.", call. = FALSE)
 
   apiKey <- check_chr(apiKey, param = "YouTube API key")
 
